@@ -46,22 +46,29 @@ setReplaceMethod("[", c("RasterLayer","missing","missing"),
 )
 
 
-.replace <- function(x, i, value) {
+.replace <- function(x, i, value, allLayers=TRUE) {
 
 	if (inherits(x, 'RasterStack')) {
 		x <- brick(x, values=TRUE)
 	}
 
 
-	if (! is.numeric(value) & !is.logical(value)) { 
-		value <- as.numeric(value) 
-	}
-		
 	if ( is.logical(i) ) {
-		i[is.na(i)] <- FALSE
+		i <- which(i)
 	} else {
+		if (! is.numeric(value)) { 
+			value <- as.numeric(value) 
+		}
 		i <- na.omit(i)
-		i <- subset(i, i >= 1 & i <= (ncell(x)*nlayers(x)) )
+	}
+
+	if (allLayers) {
+		i <- subset(i, i >= 1 & i <= ncell(x) )
+		nl <- nlayers(x)
+		if (nl > 1) {
+			add <- ncell(x) * 0:(nl-1)
+			i <- as.vector(t((matrix(rep(i, nl), nr=nl, byrow=TRUE)) + add))
+		}
 	}
 	
 	if (! inMemory(x) ) {
@@ -78,7 +85,7 @@ setReplaceMethod("[", c("RasterLayer","missing","missing"),
 		
 	x@data@values[i] <- value
 	x <- setMinMax(x)
-	x <- raster:::.clearFile(x)
+	x <- .clearFile(x)
 	return(x)
 }
 
